thedemo <- function(n=10,debug=0,secret="some-secret-of-the-data-provider",seed=0) {
    # wall clock times on a 
    # Genuine Intel(R) CPU T2300 @ 1.66GHz (dual core, 3325.09 bogomips) 
    # with R 2.9.2 and mysqld 5.1.37: 
    # 7.5sec  for n=10   (  2500 obs in total)
    #  32sec. for n=100  ( 25000 obs in total)
    # 300sec. for n=1000 (250000 obs in total)
    
    set.seed(seed)

    mysql.connection <- dbConnect(
        dbDriver("MySQL"), host="localhost", user="condense", password="condense", dbname="condense")
        dbWriteTable(mysql.connection, "test", data.frame(list(
                 g1=floor(runif(250*n)*5)
                ,g2=floor(runif(250*n)*5)
                ,g3=floor(runif(250*n)*5)
                ,test=runif(250*n)
                ,unif=runif(250*n)
                ,norm=rnorm(250*n)
                ,cauchy=rcauchy(250*n)
                ,lnorm=rlnorm(250*n)
                ,exp=rexp(250*n)
        )), overwrite=TRUE)
    
    result <- jk.means(
         connection=mysql.connection
        ,input.table="test"
        ,analyse=list(
             list(name="unif", label="uniform", quartiles=c(0,.25,.5,.75,1))
            ,list(name="norm", label="normal", quartiles=c(-Inf,-1.25,0,1.25,Inf))
            ,list(name="cauchy", label="cauchy", quartiles=c(-Inf,-1.5,0,1.6,Inf))
            ,list(name="lnorm", label="log-normal", quartiles=c(0,.5,1,2,Inf))
            ,list(name="exp", label="exponential", quartiles=c(0,.5,1,2,Inf))
        )
        ,group.by=list(
            list(name="g1", label="group 1", groups=list(
                 list(level=1, label="0..3", condition="x<4") 
                ,list(level=2, label="0", condition="x=0") 
                ,list(level=2, label="1", condition="x=1") 
                ,list(level=1, label="4", condition="x>3") 
            ))
            ,list(name="g2", label="group 2", groups=list(
                 list(level=1, label="0..3", condition="x<4") 
                ,list(level=2, label="0", condition="x=0") 
                ,list(level=2, label="1", condition="x=1") 
                ,list(level=1, label="4", condition="x>3") 
            ))
            ,list(name="g3", label="group 3", groups=list(
                 list(level=1, label="0..3", condition="x<4") 
                ,list(level=2, label="0", condition="x=0") 
                ,list(level=2, label="1", condition="x=1") 
                ,list(level=1, label="4", condition="x>3") 
            ))
        )
        ,where="test<0.5"
        ,debug=debug
        ,secret=secret
    )
    
    dbDisconnect(mysql.connection)

    return(result)
}
cat ('Note: This demo requires a local MySQL database+user+password all named "condense".\n')
cat ('Please call thedemo() or thedemo(n=...,secret="...",seed=...)\n')
